import { Observable } from 'rxjs';
import { LocalMediaHandler } from '../media/LocalMediaHandler';
import { ManagedStream } from '../media/ManagedStream';
import { Dtmf, MediaTypes } from '../types';
import { Conference as StackConference } from '../wac-proxy/stacks/Janus/Conference';
import { ConferenceStatus } from './ConferenceStatus';
export declare enum ConferenceParticipantState {
    CALLING = 0,
    IN_CALL = 1,
    HOLD = 2
}
export interface ConferenceParticipant {
    readonly id: string;
    readonly muted: boolean;
    readonly isTalking: boolean;
    readonly isLocal: boolean;
    readonly state: ConferenceParticipantState;
    readonly streams: readonly ManagedStream[];
}
export interface ConferenceInvite {
    readonly id: string;
    readonly from: string;
    readonly mediaTypes: MediaTypes;
    readonly context: Record<string, string>;
    readonly fromDetails: {
        readonly contactName: string;
        readonly displayName: string;
        readonly username: string;
    };
}
declare type ParticipantsState = Map<string, ConferenceParticipant>;
/**
 * Provides access to methods for managing outgoing or incoming conferences.
 * {@link Conference} objects are obtained calling {@link ConferenceManager#createConference} method or handling
 * the `onIncoming` event of a connected {@link ConferenceManager} instance.
 */
export declare class Conference {
    participantsMap$: Observable<ParticipantsState>;
    localParticipant$: Observable<ConferenceParticipant | undefined>;
    remoteParticipants$: Observable<readonly ConferenceParticipant[]>;
    commonStream$: Observable<ManagedStream | undefined>;
    muteRequest$: Observable<boolean>;
    status$: Observable<ConferenceStatus>;
    /**
     * Allows access to local streams and actions related to changing which local media is shared
     */
    readonly localMediaHandler: LocalMediaHandler;
    private joinTimestampValue;
    private room;
    private statusSubject;
    private localActionsSubject;
    private subscription;
    private participantsConnectable;
    private ownId;
    private lock;
    private constructor();
    static create(room: StackConference, mediaConstraints: MediaStreamConstraints, ownId: string): Conference;
    /**
     * Returns the ID of the conference
     */
    get id(): string;
    /**
     * Indicates if the conference is being recorded
     */
    get isRecorded(): boolean;
    /**
     * Returns the current status of the conference
     */
    get status(): ConferenceStatus;
    /**
     * The timestamp when the join to this conference was completed
     */
    get joinTimestamp(): number | undefined;
    /**
     * Returns the invitation to the conference if the participant was invited.
     */
    get invite(): ConferenceInvite | undefined;
    /**
     * Connects to the conference
     */
    join(): Promise<void>;
    /**
     * Invites a new participant to this conference
     * @param participant A participant can be both an internal or an external user.
     * @param mediaTypes the MediaTypes of this invitation
     * @param context Arbitrary context that can be sent when making an invite
     * @returns A promise with an object with two properties: SIP code (SIP code of the response) and
     * whoAccepted (User id of the participant that accepted the invite).
     */
    inviteParticipant(participant: string, mediaTypes?: Readonly<MediaTypes>, context?: Record<string, string>): Promise<{
        code: number;
        whoAccepted?: string;
    }>;
    /**
     * Invites a list of new participant to this conference
     */
    inviteParticipants(participants: string[], mediaTypes?: Readonly<MediaTypes>): Promise<Array<{
        code: number;
        whoAccepted?: string;
    }>>;
    /**
     * Expels a participant from this conference
     */
    expelParticipant(userId: string, session?: string): Promise<void>;
    /**
     * Expels a list of participant from this conference
     */
    expelParticipants(participants: string[]): Promise<void>;
    /**
     * Invites the voicemail to a conference
     * @param mediaTypes the media types that will be used to call the voicemail
     */
    callVoiceMail(mediaTypes?: MediaTypes): Promise<{
        code: number;
        whoAccepted?: string;
    }>;
    /**
     * Leaves the conference
     * @param errorCode the rejection cause when an invitation is received
     * and the conference has not been joined.
     */
    leave(errorCode?: number): Promise<void>;
    /**
     * Local hold
     * Stop publishing and subscribing to the media in the conference
     */
    hold(): Promise<void>;
    /**
     * Stop local hold
     * Republishes all previously published media, subscribes to previously subscribed
     * media and notifies new status to other participants.
     */
    unhold(): Promise<void>;
    /**
     * Create an unattended call transfer towards a user in the system
     * @param participant
     * @param mediaTypes the current media types will be used if nothing is specified
     */
    transfer(participant: string, mediaTypes?: Readonly<MediaTypes>): Promise<void>;
    /**
     * Send a DTMF to the conference
     * @param value The DTMF code to send
     */
    sendDtmf(value: Dtmf): Promise<void>;
    /**
     * Request a remote participant to mute their audio
     * @param to The id of the participant to mute
     * @param muted If true, requests the remote participant to turn off their microphone and if false
     * to turn it on.
     */
    muteRequest(to: string, muted?: boolean): Promise<void>;
    private getActions;
    private bindEventHandlers;
    private setStatus;
    private cancelOutgoingInvitations;
}
export {};
